package org.dromara.system.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.system.domain.SysTenant;
import org.dromara.system.domain.bo.SysReferenceBo;
import org.dromara.system.domain.bo.SysTenantBo;
import org.dromara.system.domain.bo.SysTenantExtendBo;
import org.dromara.system.domain.bo.SysTenantReviewBo;
import org.dromara.system.domain.dto.TenantDTO;
import org.dromara.system.domain.vo.SysReferenceVO;
import org.dromara.system.domain.vo.SysTenantVo;

import java.util.Collection;
import java.util.List;

/**
 * 租户Service接口
 *
 * @author Michelle.Chung
 */
public interface ISysTenantService {

    /**
     * 查询租户
     */
    SysTenantVo queryById(Long id);

    /**
     * 基于租户ID查询租户
     */
    SysTenantVo queryByTenantId(String tenantId);

    /**
     * 查询租户列表
     */
    TableDataInfo<SysTenantVo> queryPageList(SysTenantBo bo, PageQuery pageQuery);

    /**
     * 查询租户列表
     */
    List<SysTenantVo> queryList(SysTenantBo bo);

    /**
     * 新增租户
     */
    Boolean insertByBo(SysTenantExtendBo bo);

    /**
     * 修改租户
     */
    Boolean updateByBo(SysTenantExtendBo bo);

    /**
     * 修改租户状态
     */
    int updateTenantStatus(SysTenantBo bo);

    /**
     * 校验租户是否允许操作
     */
    void checkTenantAllowed(String tenantId);

    /**
     * 校验并批量删除租户信息
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);

    /**
     * 校验企业名称是否唯一
     */
    boolean checkCompanyNameUnique(String tenantId, String companyName);

    /**
     * 校验账号余额
     */
    boolean checkAccountBalance(String tenantId);

    /**
     * 校验有效期
     */
    boolean checkExpireTime(String tenantId);

    /**
     * 同步租户套餐
     */
    Boolean syncTenantPackage(String tenantId, Long packageId);

    /**
     * 同步租户字典
     */
    void syncTenantDict();

    IPage<TenantDTO> getlist(Page<SysTenant> page, SysTenantExtendBo query);

    List<TenantDTO> getAll(SysTenantBo bo);

    TenantDTO getById(Long id);


    Boolean batchRemoveByIds(List<Long> ids);

    /**
     * 提交签约
     * @param tenantId
     * @return
     */
    int submitSign(String tenantId);

    /**
     * 审核租户提交的签约
     * @param bo
     */
    void reviewSubmitted(SysTenantReviewBo bo);

    /**
     * 确认签约
     * @param tenantId
     */
    void confirmedSign(String tenantId);

    SysTenant queryByDeptId(Long deptId);

    /**
     * 根据id查询其所有子级租户
     *
     * @param id
     * @return
     */
    List<SysTenantVo> getByParentId(Long id);

    /**
     * 将团长BO转换为租户BO
     *
     * @param sysReferenceBo
     * @return
     */
    SysTenantExtendBo convert(SysReferenceBo sysReferenceBo);

    /**
     * 查询团长列表
     *
     * @param query
     * @return
     */
    IPage<SysReferenceVO> getReferenceList(SysReferenceBo query);
}
